@@ -5,9 +5,9 @@ For a list of options, run this script with the --help option.
 """
 
 # $HeadURL: http://svn.collab.net/repos/svn/branches/1.5.x/win-tests.py $
-# $LastChangedDate: 2008-01-25 16:56:46 +0000 (Fri, 25 Jan 2008) $
-# $LastChangedBy: pburba $
-# $LastChangedRevision: 29039 $
+# $LastChangedDate: 2009-02-24 21:58:43 +0000 (Tue, 24 Feb 2009) $
+# $LastChangedBy: hwright $
+# $LastChangedRevision: 36110 $
 
 import os, sys
 import filecmp
@@ -84,7 +84,8 @@ opts, args = my_getopt(sys.argv[1:], 'hrdvcpu:f:',
                        ['release', 'debug', 'verbose', 'cleanup', 'url=',
                         'svnserve-args=', 'fs-type=', 'asp.net-hack',
                         'httpd-dir=', 'httpd-port=', 'http-library=', 'help',
-                        'list', 'enable-sasl', 'bin=', 'parallel'])
+                        'list', 'enable-sasl', 'bin=', 'parallel',
+                        'server-minor-version='])
 if len(args) > 1:
   print 'Warning: non-option arguments after the first one will be ignored'
 
